@@ -19,7 +19,7 @@ accomplish their experiments.
 Developed  by
         Hakan Temiz             htemiz@artvin.edu.tr
 
-Version : 0.0.51
+Version : 0.0.52
 History :
 
 """
@@ -136,6 +136,7 @@ from keras.backend import image_data_format
 from keras.layers import Activation
 from keras.layers.advanced_activations import LeakyReLU, PReLU
 
+from epoch_sleep import EpochSleep
 
 image_extentions = ["*.bmp", "*.BMP", "*.jpg", "*.JPG", "*.png", "*.PNG", "*.jpeg", "*.JPEG", "*.TIFF", "*.tiff", '*.mat']
 
@@ -1355,6 +1356,11 @@ class DeepSR(object):
                                                patience=self.espatience,
                                                verbose=1, mode='min', min_lr=self.minimumlrate))
 
+        # Sleep after an epoch is finished. Aim of this is to
+        # protect GPUs from over heating.
+        if hasattr(self, "esleep") and self.esleep > 0:
+            callbacks.append(EpochSleep(self.esleep))
+
         # append user-defined callbacks
         if hasattr(self, "callbacks"):
             for cbk in self.callbacks():
