@@ -64,6 +64,10 @@ parser.add_argument("--decimation", type=str, choices=["bilinear", "bicubic", 'n
 parser.add_argument("--drate", type=int, nargs="+", default=(1,1),
                     help="A list of dilation rate values for layers. Default is (1,1).")
 
+parser.add_argument("--esleep", type=int, default=0,
+                    help="Integer. Time in seconds to sleep after each epoch is finished. Default is 0.")
+
+
 parser.add_argument("--espatience", type=int, default=5,
                     help="Integer. Early stopping patience. The number of training epochs to wait before early stop if the model does not progress \
                      on validation data. this parameter helps avoiding overfitting when training the model. \
