@@ -88,11 +88,27 @@ def load_mat_file(file):
 
 
 
-def RF_to_Bmode(rf):
+def RF_to_Bmode(rf, bmode =False, bmode_range=70, log_coef=10, normalize = True):
     hlb = hilbert(rf)
+    env = np.abs(hlb)
 
-    return 20 * np.log10(np.abs(hlb))
+    if normalize:
+        env = env - env.min()
+        env /= env.max()
 
+    if not bmode:
+        return log_coef * np.log10(env)
+
+    else:
+        l = log_coef * np.log10(env)
+        l = 255 * (l + bmode_range) / bmode_range
+        l[np.isneginf(l)] = 0
+        #
+        # plt.imshow(l, cmap='gray')
+        # plt.show()
+        # print(l.min(), '  ', l.max())
+        #
+        return l.astype(np.uint8)
 
 
 def get_files(path, extentions, remove_extension=True, full_path = False):
